..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Notebook Pages Example
===============================================================================

An example of using dynamic notebook pages.

This example demonstrates using the ``Include`` component to dynamically
insert and remove pages from a notebook.

.. TIP:: To see this example in action, download it from
 :download:`notebook_pages <../../../examples/dynamic/notebook_pages.enaml>`
 and run::

   $ enaml-run notebook_pages.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_notebook_pages.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/dynamic/notebook_pages.enaml
    :language: enaml
